@@ -1,31 +1,27 @@
-/*!
-ffi-safe types that aren't wrappers for other types.
-*/
-
+//! ffi-safe types that aren't wrappers for other types.
 
 mod constructor;
 mod ignored_wrapper;
 mod late_static_ref;
-mod nul_str;
 mod maybe_cmp;
 mod move_ptr;
-mod static_ref;
-mod rref;
+mod nul_str;
 mod rmut;
-pub mod version;
+mod rref;
 pub mod rsmallbox;
-
+mod static_ref;
+pub mod version;
 
 pub use self::{
-    constructor::{Constructor,ConstructorOrValue},
+    constructor::{Constructor, ConstructorOrValue},
     ignored_wrapper::CmpIgnored,
-    static_ref::StaticRef,
-    nul_str::NulStr,
+    late_static_ref::LateStaticRef,
     maybe_cmp::MaybeCmp,
     move_ptr::MovePtr,
-    rref::RRef,
+    nul_str::{NulStr, NulStrError},
     rmut::RMut,
+    rref::RRef,
     rsmallbox::RSmallBox,
-    late_static_ref::LateStaticRef,
-    version::{VersionNumber,VersionStrings,ParseVersionError},
-};
\ No newline at end of file
+    static_ref::StaticRef,
+    version::{ParseVersionError, VersionNumber, VersionStrings},
+};
