@@ -1,6 +1,4 @@
-/*!
-Contains the ffi-safe equivalent of `std::option::Option`.
-*/
+//! Contains the ffi-safe equivalent of `std::option::Option`.
 
 use std::mem;
 
@@ -8,10 +6,9 @@ use core_extensions::matches;
 
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 
-
 /// Ffi-safe equivalent of the `std::option::Option` type.
 ///
-/// `Option` is also ffi-safe for NonNull/NonZero types,and references.
+/// `Option` is also ffi-safe for NonNull/NonZero types, and references.
 ///
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Ord, PartialOrd, Hash)]
 #[repr(u8)]
@@ -30,10 +27,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .as_ref(),RSome(&10));
-    /// assert_eq!(RNone::<u32>.as_ref(),RNone     );
+    /// assert_eq!(RSome(10).as_ref(), RSome(&10));
+    /// assert_eq!(RNone::<u32>.as_ref(), RNone);
     ///
     /// ```
     #[inline]
@@ -49,10 +46,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .as_mut(),RSome(&mut 10));
-    /// assert_eq!(RNone::<u32>.as_mut(),RNone );
+    /// assert_eq!(RSome(10).as_mut(), RSome(&mut 10));
+    /// assert_eq!(RNone::<u32>.as_mut(), RNone);
     ///
     /// ```
     #[inline]
@@ -62,21 +59,21 @@ impl<T> ROption<T> {
             RNone => RNone,
         }
     }
-    
+
     /// Returns whether `self` is an `RSome`
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .is_rsome(),true);
-    /// assert_eq!(RNone::<u32>.is_rsome(),false);
+    /// assert_eq!(RSome(10).is_rsome(), true);
+    /// assert_eq!(RNone::<u32>.is_rsome(), false);
     ///
     /// ```
     #[inline]
-    pub fn is_rsome(&self)->bool{
-        matches!(self, RSome{..})
+    pub fn is_rsome(&self) -> bool {
+        matches!(self, RSome { .. })
     }
 
     /// Returns whether `self` is an `RNone`
@@ -84,32 +81,31 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .is_rnone(),false);
-    /// assert_eq!(RNone::<u32>.is_rnone(),true);
+    /// assert_eq!(RSome(10).is_rnone(), false);
+    /// assert_eq!(RNone::<u32>.is_rnone(), true);
     ///
     /// ```
     #[inline]
-    pub fn is_rnone(&self)->bool{
-        matches!(self, RNone{..})
+    pub fn is_rnone(&self) -> bool {
+        matches!(self, RNone { .. })
     }
 
-    
     /// Returns whether `self` is an `RSome`
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .is_some(),true);
-    /// assert_eq!(RNone::<u32>.is_some(),false);
+    /// assert_eq!(RSome(10).is_some(), true);
+    /// assert_eq!(RNone::<u32>.is_some(), false);
     ///
     /// ```
     #[inline]
-    pub fn is_some(&self)->bool{
-        matches!(self, RSome{..})
+    pub fn is_some(&self) -> bool {
+        matches!(self, RSome { .. })
     }
 
     /// Returns whether `self` is an `RNone`
@@ -117,27 +113,26 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .is_none(),false);
-    /// assert_eq!(RNone::<u32>.is_none(),true);
+    /// assert_eq!(RSome(10).is_none(), false);
+    /// assert_eq!(RNone::<u32>.is_none(), true);
     ///
     /// ```
     #[inline]
-    pub fn is_none(&self)->bool{
-        matches!(self, RNone{..})
+    pub fn is_none(&self) -> bool {
+        matches!(self, RNone { .. })
     }
 
-
     /// Converts from `ROption<T>` to `Option<T>`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .into_option(),Some(10));
-    /// assert_eq!(RNone::<u32>.into_option(),None     );
+    /// assert_eq!(RSome(10).into_option(), Some(10));
+    /// assert_eq!(RNone::<u32>.into_option(), None);
     ///
     /// ```
     #[inline]
@@ -146,65 +141,65 @@ impl<T> ROption<T> {
     }
 
     /// Unwraps the `ROption<T>`, returning its contents.
-    /// 
+    ///
     /// # Panics
-    /// 
+    ///
     /// Panics if `self` is `RNone`, with the `msg` message.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!( RSome(100).expect("must contain a value"), 100 );
+    /// assert_eq!(RSome(100).expect("must contain a value"), 100);
     ///
     /// ```
     ///
     /// This one panics:
     /// ```should_panic
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// let _=RNone::<()>.expect("Oh noooo!");
+    /// let _ = RNone::<()>.expect("Oh noooo!");
     /// ```
     #[inline]
     pub fn expect(self, msg: &str) -> T {
         self.into_option().expect(msg)
     }
     /// Unwraps the ROption, returning its contents.
-    /// 
+    ///
     /// # Panics
-    /// 
+    ///
     /// Panics if `self` is `RNone`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!( RSome(500).unwrap(), 500 );
+    /// assert_eq!(RSome(500).unwrap(), 500);
     ///
     /// ```
     ///
     /// This one panics:
     /// ```should_panic
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// let _=RNone::<()>.unwrap();
+    /// let _ = RNone::<()>.unwrap();
     /// ```
     #[inline]
     pub fn unwrap(self) -> T {
         self.into_option().unwrap()
     }
 
-    /// Returns the value in the `ROption<T>`,or `def` if `self` is `RNone`.
+    /// Returns the value in the `ROption<T>`, or `def` if `self` is `RNone`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .unwrap_or(99),10);
-    /// assert_eq!(RNone::<u32>.unwrap_or(99),99);
+    /// assert_eq!(RSome(10).unwrap_or(99), 10);
+    /// assert_eq!(RNone::<u32>.unwrap_or(99), 99);
     ///
     /// ```
     #[inline]
@@ -215,21 +210,21 @@ impl<T> ROption<T> {
         }
     }
 
-    /// Returns the value in the `ROption<T>`,or `T::default()` if `self` is `RNone`.
+    /// Returns the value in the `ROption<T>`, or `T::default()` if `self` is `RNone`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .unwrap_or_default(),10);
-    /// assert_eq!(RNone::<u32>.unwrap_or_default(),0);
+    /// assert_eq!(RSome(10).unwrap_or_default(), 10);
+    /// assert_eq!(RNone::<u32>.unwrap_or_default(), 0);
     ///
     /// ```
     #[inline]
-    pub fn unwrap_or_default(self) -> T 
-    where 
-        T:Default
+    pub fn unwrap_or_default(self) -> T
+    where
+        T: Default,
     {
         match self {
             RSome(x) => x,
@@ -243,10 +238,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .unwrap_or_else(|| 77 ),10);
-    /// assert_eq!(RNone::<u32>.unwrap_or_else(|| 77 ),77);
+    /// assert_eq!(RSome(10).unwrap_or_else(|| 77), 10);
+    /// assert_eq!(RNone::<u32>.unwrap_or_else(|| 77), 77);
     ///
     /// ```
     #[inline]
@@ -266,10 +261,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .map(|x| x*2 ),RSome(20));
-    /// assert_eq!(RNone::<u32>.map(|x| x*2 ),RNone);
+    /// assert_eq!(RSome(10).map(|x| x * 2), RSome(20));
+    /// assert_eq!(RNone::<u32>.map(|x| x * 2), RNone);
     ///
     /// ```
     #[inline]
@@ -289,10 +284,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .map_or(77,|x| x*2 ),20);
-    /// assert_eq!(RNone::<u32>.map_or(77,|x| x*2 ),77);
+    /// assert_eq!(RSome(10).map_or(77, |x| x * 2), 20);
+    /// assert_eq!(RNone::<u32>.map_or(77, |x| x * 2), 77);
     ///
     /// ```
     #[inline]
@@ -312,10 +307,10 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10)   .map_or_else(||77,|x| x*2 ),20);
-    /// assert_eq!(RNone::<u32>.map_or_else(||77,|x| x*2 ),77);
+    /// assert_eq!(RSome(10).map_or_else(|| 77, |x| x * 2), 20);
+    /// assert_eq!(RNone::<u32>.map_or_else(|| 77, |x| x * 2), 77);
     ///
     /// ```
     #[inline]
@@ -330,17 +325,17 @@ impl<T> ROption<T> {
         }
     }
 
-    /// Returns `self` if `predicate(&self)` is true,otherwise returns `RNone`.
+    /// Returns `self` if `predicate(&self)` is true, otherwise returns `RNone`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).filter(|x| (x%2)==0 ),RSome(10));
-    /// assert_eq!(RSome(10).filter(|x| (x%2)==1 ),RNone    );
-    /// assert_eq!(RNone::<u32>.filter(|_| true     ),RNone    );
-    /// assert_eq!(RNone::<u32>.filter(|_| false    ),RNone    );
+    /// assert_eq!(RSome(10).filter(|x| (x % 2) == 0), RSome(10));
+    /// assert_eq!(RSome(10).filter(|x| (x % 2) == 1), RNone);
+    /// assert_eq!(RNone::<u32>.filter(|_| true), RNone);
+    /// assert_eq!(RNone::<u32>.filter(|_| false), RNone);
     ///
     /// ```
     pub fn filter<P>(self, predicate: P) -> Self
@@ -355,17 +350,17 @@ impl<T> ROption<T> {
         RNone
     }
 
-    /// Returns `self` if it is `RNone`,otherwise returns `optb`.
+    /// Returns `self` if it is `RNone`, otherwise returns `optb`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).and(RSome(20)),RSome(20));
-    /// assert_eq!(RSome(10).and(RNone    ),RNone);
-    /// assert_eq!(RNone::<u32>.and(RSome(20)),RNone);
-    /// assert_eq!(RNone::<u32>.and(RNone    ),RNone);
+    /// assert_eq!(RSome(10).and(RSome(20)), RSome(20));
+    /// assert_eq!(RSome(10).and(RNone), RNone);
+    /// assert_eq!(RNone::<u32>.and(RSome(20)), RNone);
+    /// assert_eq!(RNone::<u32>.and(RNone), RNone);
     ///
     /// ```
     #[inline]
@@ -376,18 +371,18 @@ impl<T> ROption<T> {
         }
     }
 
-    /// Returns `self` if it is `RNone`, 
+    /// Returns `self` if it is `RNone`,
     /// otherwise returns the result of calling `f` with the value in `RSome`.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).and_then(|x|RSome(x * 2)),RSome(20));
-    /// assert_eq!(RSome(10).and_then(|_|RNone::<u32>),RNone);
-    /// assert_eq!(RNone::<u32>.and_then(|x|RSome(x * 2)),RNone);
-    /// assert_eq!(RNone::<u32>.and_then(|_|RNone::<u32>),RNone);
+    /// assert_eq!(RSome(10).and_then(|x| RSome(x * 2)), RSome(20));
+    /// assert_eq!(RSome(10).and_then(|_| RNone::<u32>), RNone);
+    /// assert_eq!(RNone::<u32>.and_then(|x| RSome(x * 2)), RNone);
+    /// assert_eq!(RNone::<u32>.and_then(|_| RNone::<u32>), RNone);
     ///
     /// ```
     #[inline]
@@ -406,12 +401,12 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).or(RSome(20)),RSome(10));
-    /// assert_eq!(RSome(10).or(RNone    ),RSome(10));
-    /// assert_eq!(RNone::<u32>.or(RSome(20)),RSome(20));
-    /// assert_eq!(RNone::<u32>.or(RNone    ),RNone);
+    /// assert_eq!(RSome(10).or(RSome(20)), RSome(10));
+    /// assert_eq!(RSome(10).or(RNone    ), RSome(10));
+    /// assert_eq!(RNone::<u32>.or(RSome(20)), RSome(20));
+    /// assert_eq!(RNone::<u32>.or(RNone    ), RNone);
     ///
     /// ```
     #[inline]
@@ -422,18 +417,18 @@ impl<T> ROption<T> {
         }
     }
 
-    /// Returns `self` if it contains a value, 
+    /// Returns `self` if it contains a value,
     /// otherwise calls `optb` and returns the value it evaluates to.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).or_else(|| RSome(20) ),RSome(10));
-    /// assert_eq!(RSome(10).or_else(|| RNone     ),RSome(10));
-    /// assert_eq!(RNone::<u32>.or_else(|| RSome(20) ),RSome(20));
-    /// assert_eq!(RNone::<u32>.or_else(|| RNone     ),RNone);
+    /// assert_eq!(RSome(10).or_else(|| RSome(20)), RSome(10));
+    /// assert_eq!(RSome(10).or_else(|| RNone), RSome(10));
+    /// assert_eq!(RNone::<u32>.or_else(|| RSome(20)), RSome(20));
+    /// assert_eq!(RNone::<u32>.or_else(|| RNone), RNone);
     ///
     /// ```
     #[inline]
@@ -453,12 +448,12 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).xor(RSome(20)),RNone    );
-    /// assert_eq!(RSome(10).xor(RNone    ),RSome(10));
-    /// assert_eq!(RNone::<u32>.xor(RSome(20)),RSome(20));
-    /// assert_eq!(RNone::<u32>.xor(RNone    ),RNone    );
+    /// assert_eq!(RSome(10).xor(RSome(20)), RNone);
+    /// assert_eq!(RSome(10).xor(RNone), RSome(10));
+    /// assert_eq!(RNone::<u32>.xor(RSome(20)), RSome(20));
+    /// assert_eq!(RNone::<u32>.xor(RNone), RNone);
     ///
     /// ```
     #[inline]
@@ -476,11 +471,11 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).get_or_insert(40),&mut 10);
-    /// assert_eq!(RSome(20).get_or_insert(55),&mut 20);
-    /// assert_eq!(RNone::<u32>.get_or_insert(77),&mut 77);
+    /// assert_eq!(RSome(10).get_or_insert(40), &mut 10);
+    /// assert_eq!(RSome(20).get_or_insert(55), &mut 20);
+    /// assert_eq!(RNone::<u32>.get_or_insert(77), &mut 77);
     ///
     /// ```
     #[inline]
@@ -501,11 +496,11 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(10).get_or_insert_with(||40),&mut 10);
-    /// assert_eq!(RSome(20).get_or_insert_with(||55),&mut 20);
-    /// assert_eq!(RNone::<u32>.get_or_insert_with(||77),&mut 77);
+    /// assert_eq!(RSome(10).get_or_insert_with(|| 40), &mut 10);
+    /// assert_eq!(RSome(20).get_or_insert_with(|| 55), &mut 20);
+    /// assert_eq!(RNone::<u32>.get_or_insert_with(|| 77), &mut 77);
     ///
     /// ```
     #[inline]
@@ -523,24 +518,24 @@ impl<T> ROption<T> {
         }
     }
 
-    /// Takes the value of `self`,replacing it with `RNone`
+    /// Takes the value of `self`, replacing it with `RNone`
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// let mut opt0=RSome(10);
-    /// assert_eq!(opt0.take(),RSome(10));
-    /// assert_eq!(opt0,RNone);
+    /// let mut opt0 = RSome(10);
+    /// assert_eq!(opt0.take(), RSome(10));
+    /// assert_eq!(opt0, RNone);
     ///
-    /// let mut opt1=RSome(20);
-    /// assert_eq!(opt1.take(),RSome(20));
-    /// assert_eq!(opt1,RNone);
+    /// let mut opt1 = RSome(20);
+    /// assert_eq!(opt1.take(), RSome(20));
+    /// assert_eq!(opt1, RNone);
     ///
-    /// let mut opt2=RNone::<u32>;
-    /// assert_eq!(opt2.take(),RNone);
-    /// assert_eq!(opt2,RNone);
+    /// let mut opt2 = RNone::<u32>;
+    /// assert_eq!(opt2.take(), RNone);
+    /// assert_eq!(opt2, RNone);
     ///
     /// ```
     #[inline]
@@ -553,19 +548,19 @@ impl<T> ROption<T> {
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// let mut opt0=RSome(10);
-    /// assert_eq!(opt0.replace(55),RSome(10));
-    /// assert_eq!(opt0,RSome(55));
+    /// let mut opt0 = RSome(10);
+    /// assert_eq!(opt0.replace(55), RSome(10));
+    /// assert_eq!(opt0, RSome(55));
     ///
-    /// let mut opt1=RSome(20);
-    /// assert_eq!(opt1.replace(88),RSome(20));
-    /// assert_eq!(opt1,RSome(88));
+    /// let mut opt1 = RSome(20);
+    /// assert_eq!(opt1.replace(88), RSome(20));
+    /// assert_eq!(opt1, RSome(88));
     ///
-    /// let mut opt2=RNone::<u32>;
-    /// assert_eq!(opt2.replace(33),RNone);
-    /// assert_eq!(opt2,RSome(33));
+    /// let mut opt2 = RNone::<u32>;
+    /// assert_eq!(opt2.replace(33), RNone);
+    /// assert_eq!(opt2, RSome(33));
     ///
     /// ```
     #[inline]
@@ -573,24 +568,23 @@ impl<T> ROption<T> {
         mem::replace(self, RSome(value))
     }
 }
-    
 
-impl<T> ROption<&T>{
+impl<T> ROption<&T> {
     /// Converts an `ROption<&T>` to an `ROption<T>` by cloning its contents.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(&vec![()]).cloned(),RSome(vec![()]));
-    /// assert_eq!(RNone::<&Vec<()>>.cloned(),RNone        );
+    /// assert_eq!(RSome(&vec![()]).cloned(), RSome(vec![()]));
+    /// assert_eq!(RNone::<&Vec<()>>.cloned(), RNone);
     ///
     /// ```
     #[inline]
-    pub fn cloned(self)->ROption<T>
-    where 
-        T:Clone
+    pub fn cloned(self) -> ROption<T>
+    where
+        T: Clone,
     {
         match self {
             RSome(expr) => RSome(expr.clone()),
@@ -603,16 +597,16 @@ impl<T> ROption<&T>{
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(&7).copied(),RSome(7));
-    /// assert_eq!(RNone::<&u32>.copied(),RNone);
+    /// assert_eq!(RSome(&7).copied(), RSome(7));
+    /// assert_eq!(RNone::<&u32>.copied(), RNone);
     ///
     /// ```
     #[inline]
-    pub fn copied(self)->ROption<T>
-    where 
-        T:Copy
+    pub fn copied(self) -> ROption<T>
+    where
+        T: Copy,
     {
         match self {
             RSome(expr) => RSome(*expr),
@@ -621,22 +615,22 @@ impl<T> ROption<&T>{
     }
 }
 
-impl<T> ROption<&mut T>{
+impl<T> ROption<&mut T> {
     /// Converts an `ROption<&mut T>` to a `ROption<T>` by cloning its contents.
     ///
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(&mut vec![()]).cloned(),RSome(vec![()]));
-    /// assert_eq!(RNone::<&mut Vec<()>>.cloned(),RNone    );
+    /// assert_eq!(RSome(&mut vec![()]).cloned(), RSome(vec![()]));
+    /// assert_eq!(RNone::<&mut Vec<()>>.cloned(), RNone);
     ///
     /// ```
     #[inline]
-    pub fn cloned(self)->ROption<T>
-    where 
-        T:Clone
+    pub fn cloned(self) -> ROption<T>
+    where
+        T: Clone,
     {
         match self {
             RSome(expr) => RSome(expr.clone()),
@@ -649,16 +643,16 @@ impl<T> ROption<&mut T>{
     /// # Example
     ///
     /// ```
-    /// # use abi_stable::std_types::*; 
+    /// # use abi_stable::std_types::*;
     ///
-    /// assert_eq!(RSome(&mut 7).copied(),RSome(7));
-    /// assert_eq!(RNone::<&mut u32>.copied(),RNone   );
+    /// assert_eq!(RSome(&mut 7).copied(), RSome(7));
+    /// assert_eq!(RNone::<&mut u32>.copied(), RNone);
     ///
     /// ```
     #[inline]
-    pub fn copied(self)->ROption<T>
-    where 
-        T:Copy
+    pub fn copied(self) -> ROption<T>
+    where
+        T: Copy,
     {
         match self {
             RSome(expr) => RSome(*expr),
@@ -667,15 +661,13 @@ impl<T> ROption<&mut T>{
     }
 }
 
-
 /// The default value is `RNone`.
 impl<T> Default for ROption<T> {
-    fn default()->Self{
+    fn default() -> Self {
         RNone
     }
 }
 
-
 impl_from_rust_repr! {
     impl[T] From<Option<T>> for ROption<T> {
         fn(this){
@@ -724,19 +716,17 @@ where
 
 /////////////////////////////////////////////////////////////////////
 
-
-#[cfg(all(test,not(feature="only_new_tests")))]
+#[cfg(all(test, not(feature = "only_new_tests")))]
 // #[cfg(test)]
-mod test{
+mod test {
     use super::*;
 
     #[test]
-    fn from_into(){
-        assert_eq!(ROption::from(Some(10)),RSome(10));
-        assert_eq!(ROption::from(None::<u32>),RNone    );
+    fn from_into() {
+        assert_eq!(ROption::from(Some(10)), RSome(10));
+        assert_eq!(ROption::from(None::<u32>), RNone);
 
-        assert_eq!(RSome(10).into_option(),Some(10));
-        assert_eq!(RNone::<u32>.into_option(),None    );
+        assert_eq!(RSome(10).into_option(), Some(10));
+        assert_eq!(RNone::<u32>.into_option(), None);
     }
-
 }
