@@ -13,177 +13,173 @@ use crate::{
         c_functions::{adapt_std_fmt, debug_impl, display_impl},
         FormattingMode,
     },
-    marker_type::{SyncSend, UnsyncUnsend,UnsyncSend,ErasedObject},
-    pointer_trait::{AsPtr, AsMutPtr},
-    prefix_type::{PrefixTypeTrait,WithMetadata},
+    marker_type::{ErasedObject, SyncSend, UnsyncSend, UnsyncUnsend},
+    pointer_trait::{AsMutPtr, AsPtr},
+    prefix_type::{PrefixTypeTrait, WithMetadata},
     sabi_types::RRef,
     std_types::{
+        utypeid::{new_utypeid, UTypeId},
         RBox, ROption, RResult, RStr, RString,
-        utypeid::{UTypeId,new_utypeid}
     },
     utils::transmute_reference,
 };
 
 #[cfg(test)]
-// #[cfg(all(test,not(feature="only_new_tests")))]
+// #[cfg(all(test, not(feature = "only_new_tests")))]
 mod test;
 
-/**
-Ffi-safe version of `Box<dyn std::error::Error + 'static>` 
-whose `Send + Sync`ness is determined by the `M` type parameter.
-
-# Examples
-
-### Converting from and into `Box<dyn Error + ...>`
-<span id="from_to_conversion"></span>
-```
-use std::{
-    convert::TryFrom,
-    error::Error as ErrorTrait,
-};
-
-use abi_stable::std_types::{RBox,RBoxError,UnsyncRBoxError,SendRBoxError};
-
-{
-    let from:Box<dyn ErrorTrait>= "hello,error".into();
-    let rbox=UnsyncRBoxError::from_box(from);
-    let _:Box<dyn ErrorTrait>= rbox.into_box();
-}
-
-{
-    let arr_err=<[();0]>::try_from(&[()][..]).unwrap_err();
-    let from:Box<dyn ErrorTrait+Send>= Box::new(arr_err);
-    let rbox=SendRBoxError::from_box(from);
-    let _:Box<dyn ErrorTrait+Send>= rbox.into_box();
-}
-
-{
-    let arr_err=<[();0]>::try_from(&[()][..]).unwrap_err();
-    let from:Box<dyn ErrorTrait+Send+Sync>= Box::new(arr_err);
-    let rbox=RBoxError::from_box(from);
-    let _:Box<dyn ErrorTrait+Send+Sync>= rbox.into_box();
-}
-
-```
-
-### Downcasting by value
-
-```
-use std::num::{ParseFloatError,ParseIntError};
-
-use abi_stable::std_types::{RBox,RBoxError};
-
-// Constructing a `RBoxError` from a `Box<dyn Error>`,then downcasting to a `ParseIntError`.
-{
-    let parse_err="".parse::<u64>().unwrap_err();
-    let dyn_err:Box<std::error::Error+Send+Sync+'static>=
-        Box::new(parse_err.clone());
-    let err=RBoxError::from_box(dyn_err);
-    
-    assert_eq!( err.downcast::<ParseIntError>().unwrap(), RBox::new(parse_err) );
-}
-
-// Constructing a `RBoxError` from a `ParseFloatError`,then downcasting back to it.
-{
-    let parse_err="".parse::<f32>().unwrap_err();
-    let err=RBoxError::new(parse_err.clone());
-    
-    assert_eq!( err.downcast::<ParseFloatError>().unwrap(), RBox::new(parse_err) );
-}
-
-// Constructing a `RBoxError` from a `ParseFloatError`,
-// then attempting to downcasting it to a `ParseIntError`.
-{
-    let parse_err="".parse::<f32>().unwrap_err();
-    let err=RBoxError::new(parse_err);
-    
-    assert!( err.downcast::<ParseIntError>().is_err() );
-}
-
-```
-
-### Downcasting by reference
-
-```
-use std::{
-    convert::TryFrom,
-    num::TryFromIntError,
-    str::Utf8Error,
-};
-
-use abi_stable::std_types::{RBox,UnsyncRBoxError};
-
-// Constructing a `UnsyncRBoxError` from a `Box<dyn Error>`,
-// then downcasting to a `TryFromIntError`.
-{
-    let int_err=u32::try_from(-1_i32).unwrap_err();
-    let dyn_err:Box<std::error::Error+'static>=
-        Box::new(int_err.clone());
-    let err=UnsyncRBoxError::from_box(dyn_err);
-    
-    assert_eq!( err.downcast_ref::<TryFromIntError>().unwrap(), &int_err );
-}
-
-// Constructing a `UnsyncRBoxError` from a `Utf8Error`,then downcasting back to it.
-{
-    let utf8_err=std::str::from_utf8(&[255]).unwrap_err();
-    let err=UnsyncRBoxError::new(utf8_err.clone());
-    
-    assert_eq!( err.downcast_ref::<Utf8Error>().unwrap(), &utf8_err );
-}
-
-// Constructing a `UnsyncRBoxError` from a `Utf8Error`,
-// then attempting to downcasting it to a `TryFromIntError`.
-{
-    let utf8_err=std::str::from_utf8(&[255]).unwrap_err();
-    let err=UnsyncRBoxError::new(utf8_err);
-    
-    assert!( err.downcast_ref::<TryFromIntError>().is_none() );
-}
-
-```
-
-
-### Downcasting by mutable reference
-
-```
-use std::string::{FromUtf8Error,FromUtf16Error};
-    
-use abi_stable::std_types::{RBox,SendRBoxError};
-
-// Constructing a `SendRBoxError` from a `Box<dyn Error>`,
-// then downcasting to a `FromUtf8Error`.
-{
-    let str_err=|| String::from_utf8(vec![255]).unwrap_err() ;
-    let dyn_err:Box<std::error::Error+Send+'static>=
-        Box::new(str_err());
-    let mut err=SendRBoxError::from_box(dyn_err);
-    
-    assert!( err.downcast_ref::<FromUtf8Error>().is_some() ,"part A");
-}
-
-// Constructing a `SendRBoxError` from a `FromUtf8Error`,then downcasting back to it.
-{
-    let str_err=|| String::from_utf8(vec![255]).unwrap_err() ;
-    let mut err=SendRBoxError::new(str_err());
-    
-    assert!( err.downcast_ref::<FromUtf8Error>().is_some() ,"part B");
-}
-
-// Constructing a `SendRBoxError` from a `FromUtf16Error`,
-// then attempting to downcasting it to a `FromUtf8Error`.
-{
-    let str_err=|| String::from_utf16(&[0xD834]).unwrap_err() ;
-    let mut err=SendRBoxError::new(str_err());
-    
-    assert!( err.downcast_ref::<FromUtf8Error>().is_none() ,"part C");
-}
-
-```
-
-
-
-*/
+/// Ffi-safe version of `Box<dyn std::error::Error + 'static>`
+/// whose `Send + Sync`ness is determined by the `M` type parameter.
+///
+/// # Examples
+///
+/// ### Converting from and into `Box<dyn Error + ...>`
+/// <span id = "from_to_conversion"></span>
+/// ```
+/// use std::{convert::TryFrom, error::Error as ErrorTrait};
+///
+/// use abi_stable::std_types::{RBox, RBoxError, SendRBoxError, UnsyncRBoxError};
+///
+/// {
+///     let from: Box<dyn ErrorTrait> = "hello, error".into();
+///     let rbox = UnsyncRBoxError::from_box(from);
+///     let _: Box<dyn ErrorTrait> = rbox.into_box();
+/// }
+///
+/// {
+///     let arr_err = <[(); 0]>::try_from(&[()][..]).unwrap_err();
+///     let from: Box<dyn ErrorTrait + Send> = Box::new(arr_err);
+///     let rbox = SendRBoxError::from_box(from);
+///     let _: Box<dyn ErrorTrait + Send> = rbox.into_box();
+/// }
+///
+/// {
+///     let arr_err = <[(); 0]>::try_from(&[()][..]).unwrap_err();
+///     let from: Box<dyn ErrorTrait + Send + Sync> = Box::new(arr_err);
+///     let rbox = RBoxError::from_box(from);
+///     let _: Box<dyn ErrorTrait + Send + Sync> = rbox.into_box();
+/// }
+///
+///
+/// ```
+///
+/// ### Downcasting by value
+///
+/// ```
+/// use std::num::{ParseFloatError, ParseIntError};
+///
+/// use abi_stable::std_types::{RBox, RBoxError};
+///
+/// // Constructing a `RBoxError` from a `Box<dyn Error>`, then downcasting to a `ParseIntError`.
+/// {
+///     let parse_err = "".parse::<u64>().unwrap_err();
+///     let dyn_err: Box<std::error::Error + Send + Sync + 'static> =
+///         Box::new(parse_err.clone());
+///     let err = RBoxError::from_box(dyn_err);
+///
+///     assert_eq!(
+///         err.downcast::<ParseIntError>().unwrap(),
+///         RBox::new(parse_err)
+///     );
+/// }
+///
+/// // Constructing a `RBoxError` from a `ParseFloatError`, then downcasting back to it.
+/// {
+///     let parse_err = "".parse::<f32>().unwrap_err();
+///     let err = RBoxError::new(parse_err.clone());
+///
+///     assert_eq!(
+///         err.downcast::<ParseFloatError>().unwrap(),
+///         RBox::new(parse_err)
+///     );
+/// }
+///
+/// // Constructing a `RBoxError` from a `ParseFloatError`,
+/// // then attempting to downcasting it to a `ParseIntError`.
+/// {
+///     let parse_err = "".parse::<f32>().unwrap_err();
+///     let err = RBoxError::new(parse_err);
+///
+///     assert!(err.downcast::<ParseIntError>().is_err());
+/// }
+///
+/// ```
+///
+/// ### Downcasting by reference
+///
+/// ```
+/// use std::{convert::TryFrom, num::TryFromIntError, str::Utf8Error};
+///
+/// use abi_stable::std_types::{RBox, UnsyncRBoxError};
+///
+/// // Constructing a `UnsyncRBoxError` from a `Box<dyn Error>`,
+/// // then downcasting to a `TryFromIntError`.
+/// {
+///     let int_err = u32::try_from(-1_i32).unwrap_err();
+///     let dyn_err: Box<std::error::Error + 'static> = Box::new(int_err.clone());
+///     let err = UnsyncRBoxError::from_box(dyn_err);
+///
+///     assert_eq!(err.downcast_ref::<TryFromIntError>().unwrap(), &int_err);
+/// }
+///
+/// // Constructing a `UnsyncRBoxError` from a `Utf8Error`, then downcasting back to it.
+/// {
+///     let utf8_err = std::str::from_utf8(&[255]).unwrap_err();
+///     let err = UnsyncRBoxError::new(utf8_err.clone());
+///
+///     assert_eq!(err.downcast_ref::<Utf8Error>().unwrap(), &utf8_err);
+/// }
+///
+/// // Constructing a `UnsyncRBoxError` from a `Utf8Error`,
+/// // then attempting to downcasting it to a `TryFromIntError`.
+/// {
+///     let utf8_err = std::str::from_utf8(&[255]).unwrap_err();
+///     let err = UnsyncRBoxError::new(utf8_err);
+///
+///     assert!(err.downcast_ref::<TryFromIntError>().is_none());
+/// }
+///
+/// ```
+///
+///
+/// ### Downcasting by mutable reference
+///
+/// ```
+/// use std::string::{FromUtf16Error, FromUtf8Error};
+///
+/// use abi_stable::std_types::{RBox, SendRBoxError};
+///
+/// // Constructing a `SendRBoxError` from a `Box<dyn Error>`,
+/// // then downcasting to a `FromUtf8Error`.
+/// {
+///     let str_err = || String::from_utf8(vec![255]).unwrap_err();
+///     let dyn_err: Box<std::error::Error + Send + 'static> = Box::new(str_err());
+///     let mut err = SendRBoxError::from_box(dyn_err);
+///
+///     assert!(err.downcast_ref::<FromUtf8Error>().is_some(), "part A");
+/// }
+///
+/// // Constructing a `SendRBoxError` from a `FromUtf8Error`, then downcasting back to it.
+/// {
+///     let str_err = || String::from_utf8(vec![255]).unwrap_err();
+///     let mut err = SendRBoxError::new(str_err());
+///
+///     assert!(err.downcast_ref::<FromUtf8Error>().is_some(), "part B");
+/// }
+///
+/// // Constructing a `SendRBoxError` from a `FromUtf16Error`,
+/// // then attempting to downcasting it to a `FromUtf8Error`.
+/// {
+///     let str_err = || String::from_utf16(&[0xD834]).unwrap_err();
+///     let mut err = SendRBoxError::new(str_err());
+///
+///     assert!(err.downcast_ref::<FromUtf8Error>().is_none(), "part C");
+/// }
+///
+/// ```
+///
+///
+///
 #[repr(C)]
 #[derive(StableAbi)]
 pub struct RBoxError_<M = SyncSend> {
@@ -201,7 +197,6 @@ pub type SendRBoxError = RBoxError_<UnsyncSend>;
 /// Ffi safe equivalent to `Box<dyn std::error::Error + Send + Sync>`.
 pub type RBoxError = RBoxError_<SyncSend>;
 
-
 impl RBoxError_<SyncSend> {
     /// Constructs a `Send + Sync` `RBoxError_` from an error.
     ///
@@ -210,9 +205,9 @@ impl RBoxError_<SyncSend> {
     /// ```
     /// use abi_stable::std_types::RBoxError;
     ///
-    /// let str_err=String::from_utf8(vec![255]).unwrap_err();
+    /// let str_err = String::from_utf8(vec![255]).unwrap_err();
     ///
-    /// let err=RBoxError::new(str_err);
+    /// let err = RBoxError::new(str_err);
     /// ```
     pub fn new<T>(value: T) -> Self
     where
@@ -222,7 +217,6 @@ impl RBoxError_<SyncSend> {
     }
 }
 
-
 impl RBoxError_<UnsyncSend> {
     /// Constructs a `Send + !Sync` `RBoxError_` from an error.
     ///
@@ -231,9 +225,9 @@ impl RBoxError_<UnsyncSend> {
     /// ```
     /// use abi_stable::std_types::SendRBoxError;
     ///
-    /// let str_err=String::from_utf16(&[0xD834]).unwrap_err() ;
+    /// let str_err = String::from_utf16(&[0xD834]).unwrap_err() ;
     ///
-    /// let err=SendRBoxError::new(str_err);
+    /// let err = SendRBoxError::new(str_err);
     /// ```
     pub fn new<T>(value: T) -> Self
     where
@@ -243,7 +237,6 @@ impl RBoxError_<UnsyncSend> {
     }
 }
 
-
 impl RBoxError_<UnsyncUnsend> {
     /// Constructs a `!Send + !Sync` `RBoxError_` from an error.
     ///
@@ -252,9 +245,9 @@ impl RBoxError_<UnsyncUnsend> {
     /// ```
     /// use abi_stable::std_types::UnsyncRBoxError;
     ///
-    /// let str_err=std::str::from_utf8(&[255]).unwrap_err() ;
+    /// let str_err = std::str::from_utf8(&[255]).unwrap_err() ;
     ///
-    /// let err=UnsyncRBoxError::new(str_err);
+    /// let err = UnsyncRBoxError::new(str_err);
     /// ```
     pub fn new<T>(value: T) -> Self
     where
@@ -264,7 +257,6 @@ impl RBoxError_<UnsyncUnsend> {
     }
 }
 
-
 impl<M> RBoxError_<M> {
     /// Constructs an RBoxError from an error,
     /// storing the Debug and Display messages without storing the error value.
@@ -274,15 +266,15 @@ impl<M> RBoxError_<M> {
     /// ```
     /// use abi_stable::std_types::RBoxError;
     ///
-    /// let int_error="".parse::<u32>().unwrap_err();
+    /// let int_error = "".parse::<u32>().unwrap_err();
     ///
-    /// let display_fmt=int_error.to_string();
-    /// let debug_fmt=format!("{:#?}",int_error);
+    /// let display_fmt = int_error.to_string();
+    /// let debug_fmt = format!("{:#?}", int_error);
     ///
-    /// let err=RBoxError::from_fmt(&int_error);
+    /// let err = RBoxError::from_fmt(&int_error);
     ///
-    /// assert_eq!(display_fmt,err.to_string());
-    /// assert_eq!(debug_fmt,format!("{:?}",err));
+    /// assert_eq!(display_fmt, err.to_string());
+    /// assert_eq!(debug_fmt, format!("{:?}", err));
     /// ```
     pub fn from_fmt<T>(value: &T) -> Self
     where
@@ -303,13 +295,13 @@ impl<M> RBoxError_<M> {
     /// ```
     /// use abi_stable::std_types::RBoxError;
     ///
-    /// let int_error="".parse::<u32>().unwrap_err();
+    /// let int_error = "".parse::<u32>().unwrap_err();
     ///
-    /// let debug_fmt=format!("{:#?}",int_error);
-    /// let err=RBoxError::from_debug(&int_error);
+    /// let debug_fmt = format!("{:#?}", int_error);
+    /// let err = RBoxError::from_debug(&int_error);
     ///
-    /// assert_eq!(debug_fmt,format!("{}",err));
-    /// assert_eq!(debug_fmt,format!("{:#?}",err));
+    /// assert_eq!(debug_fmt, format!("{}", err));
+    /// assert_eq!(debug_fmt, format!("{:#?}", err));
     /// ```
     pub fn from_debug<T>(value: &T) -> Self
     where
@@ -323,44 +315,41 @@ impl<M> RBoxError_<M> {
     }
 
     fn from_debug_display(value: DebugDisplay) -> Self {
-        unsafe {
-            Self::new_with_vtable(value, MakeRErrorVTable::LIB_VTABLE_DEBUG_DISPLAY)
-        }
+        unsafe { Self::new_with_vtable(value, MakeRErrorVTable::LIB_VTABLE_DEBUG_DISPLAY) }
     }
 
     fn new_inner<T>(value: T) -> Self
     where
         T: ErrorTrait + 'static,
     {
-        unsafe {
-            Self::new_with_vtable(value, MakeRErrorVTable::<T>::LIB_VTABLE)
-        }
+        unsafe { Self::new_with_vtable(value, MakeRErrorVTable::<T>::LIB_VTABLE) }
     }
 
-    fn new_with_vtable<T>(value: T, vtable: RErrorVTable_Ref) -> Self{
-        unsafe {
-            let value = value
-                .piped(RBox::new)
-                .piped(|x| mem::transmute::<RBox<T>, RBox<ErasedObject>>(x));
+    unsafe fn new_with_vtable<T>(value: T, vtable: RErrorVTable_Ref) -> Self {
+        let value = value
+            .piped(RBox::new)
+            .piped(|x| mem::transmute::<RBox<T>, RBox<ErasedObject>>(x));
 
-            Self {
-                value,
-                vtable,
-                _sync_send: PhantomData,
-            }
+        Self {
+            value,
+            vtable,
+            _sync_send: PhantomData,
         }
     }
 }
 
-impl<M> RBoxError_<M>{
-    /// Converts this error to a formatted error 
-    /// 
+impl<M> RBoxError_<M> {
+    /// Converts this error to a formatted error
+    ///
     /// This is used to decouple an `RBoxError` from the dynamic library that produced it,
     /// in order to unload the dynamic library.
-    /// 
+    ///
+    // This isn't strictly required anymore because abi_stable doesn't
+    // unload libraries right now.
+    ///
     pub fn to_formatted_error<N>(&self) -> RBoxError_<N> {
         if let Some(dd) = self.as_debug_display() {
-            RBoxError_::from_debug_display(DebugDisplay{
+            RBoxError_::from_debug_display(DebugDisplay {
                 debug: dd.debug.into(),
                 display: dd.display.into(),
             })
@@ -369,29 +358,26 @@ impl<M> RBoxError_<M>{
         }
     }
 
-    fn as_debug_display(&self)->Option<DebugDisplayRef<'_>>{
-        unsafe{
-            self.vtable.as_debug_display()(self.value.as_rref())
-                .into_option()
-        }
+    fn as_debug_display(&self) -> Option<DebugDisplayRef<'_>> {
+        unsafe { self.vtable.as_debug_display()(self.value.as_rref()).into_option() }
     }
 }
 
 impl<M> RBoxError_<M> {
     /// Returns the `UTypeId` of the error this wraps.
-    pub fn type_id(&self)->UTypeId{
+    pub fn type_id(&self) -> UTypeId {
         self.vtable.type_id()()
     }
 
-    fn is_type<T:'static>(&self)->bool{
-        let self_id=self.vtable.type_id()();
-        let other_id=UTypeId::new::<T>();
-        self_id==other_id
+    fn is_type<T: 'static>(&self) -> bool {
+        let self_id = self.vtable.type_id()();
+        let other_id = UTypeId::new::<T>();
+        self_id == other_id
     }
 
     /// The address of the `Box<_>` this wraps
-    pub fn heap_address(&self)->usize{
-        (self.value.as_ptr())as *const _ as usize
+    pub fn heap_address(&self) -> usize {
+        (self.value.as_ptr()) as *const _ as usize
     }
 
     /// Casts this `&RBoxError_<_>` to `&UnsyncRBoxError`.
@@ -399,20 +385,18 @@ impl<M> RBoxError_<M> {
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RBoxError,UnsyncRBoxError};
+    /// use abi_stable::std_types::{RBoxError, UnsyncRBoxError};
     /// use std::convert::TryFrom;
     ///
-    /// let int_err=u32::try_from(-1_i32).unwrap_err();
+    /// let int_err = u32::try_from(-1_i32).unwrap_err();
     ///
-    /// let err:RBoxError=RBoxError::new(int_err);
+    /// let err: RBoxError = RBoxError::new(int_err);
     ///
-    /// let unsync_err:&UnsyncRBoxError=err.as_unsync();
+    /// let unsync_err: &UnsyncRBoxError = err.as_unsync();
     ///
     /// ```
-    pub fn as_unsync(&self)->&UnsyncRBoxError{
-        unsafe{
-            transmute_reference::<RBoxError_<M>,UnsyncRBoxError>(self)
-        }
+    pub fn as_unsync(&self) -> &UnsyncRBoxError {
+        unsafe { transmute_reference::<RBoxError_<M>, UnsyncRBoxError>(self) }
     }
 
     /// Converts this `RBoxError_<_>` to `UnsyncRBoxError`.
@@ -420,45 +404,40 @@ impl<M> RBoxError_<M> {
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RBoxError,UnsyncRBoxError};
+    /// use abi_stable::std_types::{RBoxError, UnsyncRBoxError};
     /// use std::convert::TryFrom;
     ///
-    /// let int_err=u64::try_from(-1338_i32).unwrap_err();
+    /// let int_err = u64::try_from(-1338_i32).unwrap_err();
     ///
-    /// let err:RBoxError=RBoxError::new(int_err);
+    /// let err: RBoxError = RBoxError::new(int_err);
     ///
-    /// let unsync_err:UnsyncRBoxError=err.into_unsync();
+    /// let unsync_err: UnsyncRBoxError = err.into_unsync();
     ///
     /// ```
-    pub fn into_unsync(self)->UnsyncRBoxError{
-        unsafe{
-            mem::transmute::<RBoxError_<M>,UnsyncRBoxError>(self)
-        }
+    pub fn into_unsync(self) -> UnsyncRBoxError {
+        unsafe { mem::transmute::<RBoxError_<M>, UnsyncRBoxError>(self) }
     }
 }
 
-
-impl RBoxError_<SyncSend>{
+impl RBoxError_<SyncSend> {
     /// Casts this `&RBoxError_<_>` to `&SendRBoxError`.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RBoxError,SendRBoxError};
+    /// use abi_stable::std_types::{RBoxError, SendRBoxError};
     /// use std::convert::TryFrom;
     ///
-    /// let slice:&mut [u32]=&mut [];
+    /// let slice: &mut [u32] = &mut [];
     /// let arr_err=<&mut [u32;10]>::try_from(slice).unwrap_err();
     ///
-    /// let err:RBoxError=RBoxError::new(arr_err);
+    /// let err: RBoxError = RBoxError::new(arr_err);
     ///
-    /// let unsync_err:&SendRBoxError=err.as_send();
+    /// let unsync_err: &SendRBoxError = err.as_send();
     ///
     /// ```
-    pub fn as_send(&self)->&SendRBoxError{
-        unsafe{
-            transmute_reference::<RBoxError_<SyncSend>,SendRBoxError>(self)
-        }
+    pub fn as_send(&self) -> &SendRBoxError {
+        unsafe { transmute_reference::<RBoxError_<SyncSend>, SendRBoxError>(self) }
     }
 
     /// Converts this `RBoxError_<_>` to `SendRBoxError`.
@@ -466,75 +445,66 @@ impl RBoxError_<SyncSend>{
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RBoxError,SendRBoxError};
+    /// use abi_stable::std_types::{RBoxError, SendRBoxError};
     /// use std::convert::TryFrom;
     ///
-    /// let slice:&[u32]=&[];
+    /// let slice: &[u32] = &[];
     /// let arr_err=<&[u32;10]>::try_from(slice).unwrap_err();
     ///
-    /// let err:RBoxError=RBoxError::new(arr_err);
+    /// let err: RBoxError = RBoxError::new(arr_err);
     ///
-    /// let unsync_err:SendRBoxError=err.into_send();
+    /// let unsync_err: SendRBoxError = err.into_send();
     ///
     /// ```
-    pub fn into_send(self)->SendRBoxError{
-        unsafe{
-            mem::transmute::<RBoxError_<SyncSend>,SendRBoxError>(self)
-        }
+    pub fn into_send(self) -> SendRBoxError {
+        unsafe { mem::transmute::<RBoxError_<SyncSend>, SendRBoxError>(self) }
     }
 }
 
-
-
 impl<M> ErrorTrait for RBoxError_<M> {}
 
 impl<M> Display for RBoxError_<M> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        unsafe{
-            adapt_std_fmt(self.value.as_rref(), self.vtable.display(), f)
-        }
+        unsafe { adapt_std_fmt(self.value.as_rref(), self.vtable.display(), f) }
     }
 }
 
 impl<M> Debug for RBoxError_<M> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        unsafe{
-            adapt_std_fmt(self.value.as_rref(), self.vtable.debug(), f)
-        }
+        unsafe { adapt_std_fmt(self.value.as_rref(), self.vtable.debug(), f) }
     }
 }
 
 ////////////////////////////////////////////////////////////////////////
 
-
 macro_rules! from_impls {
     (
-        $first_docs:expr,
-        $boxdyn:ty,
-        $marker:ty,
-    ) => (
-        impl From<$boxdyn> for RBoxError_<$marker>{
+        $first_docs: expr,
+        $boxdyn: ty,
+        $marker: ty,
+    ) => {
+        impl From<$boxdyn> for RBoxError_<$marker> {
             #[doc = $first_docs]
             ///
-            /// # Behavior 
+            /// # Behavior
             ///
             /// If the contents of the Box<_> is an erased `RBoxError_<_>`
             /// it will be returned directly,
             /// otherwise the `Box<_>` will be converted into an `RBoxError_<_>`
             /// using `RBoxError_::new`.
             ///
-            fn from(this:$boxdyn)->RBoxError_<$marker>{
+            fn from(this: $boxdyn) -> RBoxError_<$marker> {
                 Self::from_box(this)
             }
         }
 
-        impl RBoxError_<$marker>{
+        impl RBoxError_<$marker> {
             #[doc = $first_docs]
             ///
-            /// `RBoxError::from_box( RBoxError::into_box( err ) )` 
+            /// `RBoxError::from_box( RBoxError::into_box( err ) )`
             /// is a no-op with respect to the heap address of the RBoxError_<_>.
             ///
-            /// # Behavior 
+            /// # Behavior
             ///
             /// If the contents of the `Box<_>` is an erased `RBoxError_<_>`
             /// it will be returned directly,
@@ -545,26 +515,24 @@ macro_rules! from_impls {
             ///
             /// For an example of converting back and forth to a `Box<dyn Error>`
             /// [here is the example](#from_to_conversion).
-            pub fn from_box(this:$boxdyn)->Self{
+            pub fn from_box(this: $boxdyn) -> Self {
                 match this.downcast::<Self>() {
-                    Ok(e)=>{
-                        *e
-                    }
-                    Err(e)=>{
+                    Ok(e) => *e,
+                    Err(e) => unsafe {
                         Self::new_with_vtable::<$boxdyn>(
                             e,
                             MakeBoxedRErrorVTable::<$boxdyn>::LIB_VTABLE,
                         )
-                    }
+                    },
                 }
             }
 
             /// Converts an `RBoxError_<_>` to a `Box<dyn Error>`.
             ///
-            /// `RBoxError::from_box( RBoxError::into_box( err ) )` 
+            /// `RBoxError::from_box( RBoxError::into_box( err ) )`
             /// is a no-op with respect to the heap address of the RBoxError_<_>.
             ///
-            /// # Behavior 
+            /// # Behavior
             ///
             /// If the contents of the `RBoxError_<_>` is an erased `Box<dyn Error + ... >`
             /// it will be returned directly,
@@ -575,13 +543,13 @@ macro_rules! from_impls {
             ///
             /// For an example of converting back and forth to a `Box<dyn Error>`
             /// [here is the example](#from_to_conversion).
-            pub fn into_box(self)->$boxdyn{
+            pub fn into_box(self) -> $boxdyn {
                 if self.is_type::<$boxdyn>() {
-                    unsafe{
-                        let box_=mem::transmute::<RBox<ErasedObject>, RBox<$boxdyn>>(self.value);
+                    unsafe {
+                        let box_ = mem::transmute::<RBox<ErasedObject>, RBox<$boxdyn>>(self.value);
                         RBox::into_inner(box_)
                     }
-                }else{
+                } else {
                     Box::new(self)
                 }
             }
@@ -603,27 +571,23 @@ macro_rules! from_impls {
             ///
             /// # Example
             ///
-            /// Look at the type level documentation for 
+            /// Look at the type level documentation for
             /// [the example](#downcasting-by-value).
             ///
-            pub fn downcast<T>(self)->Result<RBox<T>,Self>
+            pub fn downcast<T>(self) -> Result<RBox<T>, Self>
             where
-                T:ErrorTrait+'static
+                T: ErrorTrait + 'static,
             {
-                match (self.is_type::<T>(),self.is_type::<$boxdyn>()) {
-                    (true,_)=>{
-                        unsafe{
-                            Ok(mem::transmute::<RBox<ErasedObject>, RBox<T>>(self.value))
-                        }
-                    }
-                    (false,true) if self.downcast_ref::<T>().is_some() =>{
-                        unsafe{
-                            let x=mem::transmute::<RBox<ErasedObject>,RBox<$boxdyn>>(self.value);
-                            let x=RBox::into_inner(x);
-                            Ok(RBox::from_box(x.downcast::<T>().unwrap()))
-                        }
-                    }
-                    (false,_)=>Err(self),
+                match (self.is_type::<T>(), self.is_type::<$boxdyn>()) {
+                    (true, _) => unsafe {
+                        Ok(mem::transmute::<RBox<ErasedObject>, RBox<T>>(self.value))
+                    },
+                    (false, true) if self.downcast_ref::<T>().is_some() => unsafe {
+                        let x = mem::transmute::<RBox<ErasedObject>, RBox<$boxdyn>>(self.value);
+                        let x = RBox::into_inner(x);
+                        Ok(RBox::from_box(x.downcast::<T>().unwrap()))
+                    },
+                    (false, _) => Err(self),
                 }
             }
 
@@ -647,23 +611,17 @@ macro_rules! from_impls {
             /// Look at the type level documentation for the example.
             /// [the example](#downcasting-by-reference).
             ///
-            pub fn downcast_ref<T>(&self)->Option<&T>
+            pub fn downcast_ref<T>(&self) -> Option<&T>
             where
-                T:ErrorTrait+'static
+                T: ErrorTrait + 'static,
             {
-                match (self.is_type::<T>(),self.is_type::<$boxdyn>()) {
-                    (true,_)=>{
-                        unsafe{
-                            Some(&*(self.value.as_ptr() as *const T))
-                        }
-                    }
-                    (false,true)=>{
-                        unsafe{
-                            let ref_box=&*(self.value.as_ptr() as *const $boxdyn);
-                            (&**ref_box).downcast_ref::<T>()
-                        }
-                    }
-                    (false,false)=>None,
+                match (self.is_type::<T>(), self.is_type::<$boxdyn>()) {
+                    (true, _) => unsafe { Some(&*(self.value.as_ptr() as *const T)) },
+                    (false, true) => unsafe {
+                        let ref_box = &*(self.value.as_ptr() as *const $boxdyn);
+                        (&**ref_box).downcast_ref::<T>()
+                    },
+                    (false, false) => None,
                 }
             }
 
@@ -687,108 +645,89 @@ macro_rules! from_impls {
             /// Look at the type level documentation for the example.
             /// [the example](#downcasting-by-mutable-reference).
             ///
-            pub fn downcast_mut<T>(&mut self)->Option<&mut T>
+            pub fn downcast_mut<T>(&mut self) -> Option<&mut T>
             where
-                T:ErrorTrait+'static
+                T: ErrorTrait + 'static,
             {
-                match (self.is_type::<T>(),self.is_type::<$boxdyn>()) {
-                    (true,_)=>{
-                        unsafe{
-                            Some(&mut *(self.value.as_mut_ptr() as *mut T))
-                        }
-                    }
-                    (false,true)=>{
-                        unsafe{
-                            let mut_box = &mut *(self.value.as_mut_ptr() as *mut $boxdyn);
-                            (&mut **mut_box).downcast_mut::<T>()
-                        }
-                    }
-                    (false,false)=>None,
+                match (self.is_type::<T>(), self.is_type::<$boxdyn>()) {
+                    (true, _) => unsafe { Some(&mut *(self.value.as_mut_ptr() as *mut T)) },
+                    (false, true) => unsafe {
+                        let mut_box = &mut *(self.value.as_mut_ptr() as *mut $boxdyn);
+                        (&mut **mut_box).downcast_mut::<T>()
+                    },
+                    (false, false) => None,
                 }
             }
         }
-    )
+    };
 }
 
-
-from_impls!{
+from_impls! {
     "Converts a `Box<dyn Error + Send + Sync>` to a `Send + Sync` `RBoxError_`.",
     Box<dyn ErrorTrait + Send + Sync + 'static> ,
     SyncSend,
 }
-from_impls!{
+from_impls! {
     "Converts a `Box<dyn Error + Send>` to a `Send + !Sync` `RBoxError_`.",
     Box<dyn ErrorTrait + Send + 'static> ,
     UnsyncSend,
 }
-from_impls!{
+from_impls! {
     "Converts a `Box<dyn Error>` to a `!Send + !Sync` `RBoxError_`.",
     Box<dyn ErrorTrait + 'static> ,
     UnsyncUnsend,
 }
 
-
-
 ////////////////////////////////////////////////////////////////////////
 
 #[repr(C)]
 #[derive(StableAbi)]
 #[sabi(kind(Prefix))]
 struct RErrorVTable {
-    debug: 
-        unsafe extern "C" fn(
-            RRef<'_, ErasedObject>,
-            FormattingMode,
-            &mut RString,
-        ) -> RResult<(), ()>,
+    debug: unsafe extern "C" fn(
+        RRef<'_, ErasedObject>,
+        FormattingMode,
+        &mut RString,
+    ) -> RResult<(), ()>,
 
-    display: 
-        unsafe extern "C" fn(
-            RRef<'_, ErasedObject>,
-            FormattingMode,
-            &mut RString,
-        ) -> RResult<(), ()>,
+    display: unsafe extern "C" fn(
+        RRef<'_, ErasedObject>,
+        FormattingMode,
+        &mut RString,
+    ) -> RResult<(), ()>,
 
-    as_debug_display: 
-        unsafe extern "C" fn(RRef<'_, ErasedObject>) -> ROption<DebugDisplayRef<'_>>,
+    as_debug_display: unsafe extern "C" fn(RRef<'_, ErasedObject>) -> ROption<DebugDisplayRef<'_>>,
 
     #[sabi(last_prefix_field)]
-    type_id: extern "C" fn()->UTypeId,
+    type_id: extern "C" fn() -> UTypeId,
 }
 
 ///////////////////
 
 struct MakeRErrorVTable<T>(T);
 
-
 impl<T> MakeRErrorVTable<T>
-where T:ErrorTrait+'static
+where
+    T: ErrorTrait + 'static,
 {
-    const VALUE:RErrorVTable=RErrorVTable{
+    const VALUE: RErrorVTable = RErrorVTable {
         debug: debug_impl::<T>,
         display: display_impl::<T>,
         as_debug_display: not_as_debug_display,
         type_id: new_utypeid::<T>,
     };
 
-    const VALUE_MD: &'static WithMetadata<RErrorVTable> = 
-        &WithMetadata::new(
-            PrefixTypeTrait::METADATA,
-            Self::VALUE,
-        );
+    const VALUE_MD: &'static WithMetadata<RErrorVTable> =
+        &WithMetadata::new(PrefixTypeTrait::METADATA, Self::VALUE);
 
-    const LIB_VTABLE: RErrorVTable_Ref = {
-        RErrorVTable_Ref(
-            Self::VALUE_MD.static_as_prefix()
-        )
-    };
+    const LIB_VTABLE: RErrorVTable_Ref = { RErrorVTable_Ref(Self::VALUE_MD.static_as_prefix()) };
 }
 
 impl MakeRErrorVTable<DebugDisplay> {
     const WM_DEBUG_DISPLAY: &'static WithMetadata<RErrorVTable> = {
         &WithMetadata::new(
             PrefixTypeTrait::METADATA,
-            RErrorVTable{
+            RErrorVTable {
                 debug: debug_impl::<DebugDisplay>,
                 display: display_impl::<DebugDisplay>,
                 as_debug_display,
@@ -797,29 +736,26 @@ impl MakeRErrorVTable<DebugDisplay> {
         )
     };
 
-    const LIB_VTABLE_DEBUG_DISPLAY: RErrorVTable_Ref = {
-        RErrorVTable_Ref(
-            Self::WM_DEBUG_DISPLAY.static_as_prefix()
-        )
-    };
+    const LIB_VTABLE_DEBUG_DISPLAY: RErrorVTable_Ref =
+        { RErrorVTable_Ref(Self::WM_DEBUG_DISPLAY.static_as_prefix()) };
 }
 
 ///////////////////
 
 struct MakeBoxedRErrorVTable<T>(T);
 
-
 impl<T> MakeBoxedRErrorVTable<Box<T>>
-where T:?Sized+ErrorTrait+'static
+where
+    T: ?Sized + ErrorTrait + 'static,
 {
-    const VALUE:RErrorVTable=RErrorVTable{
+    const VALUE: RErrorVTable = RErrorVTable {
         debug: debug_impl::<Box<T>>,
         display: display_impl::<Box<T>>,
         as_debug_display: not_as_debug_display,
         type_id: new_utypeid::<Box<T>>,
     };
 
-    const WM_VTABLE: &'static WithMetadata<RErrorVTable> = 
+    const WM_VTABLE: &'static WithMetadata<RErrorVTable> =
         &WithMetadata::new(PrefixTypeTrait::METADATA, Self::VALUE);
 
     const LIB_VTABLE: RErrorVTable_Ref = RErrorVTable_Ref(Self::WM_VTABLE.static_as_prefix());
@@ -863,7 +799,7 @@ unsafe extern "C" fn as_debug_display(
     this: RRef<'_, ErasedObject>,
 ) -> ROption<DebugDisplayRef<'_>> {
     extern_fn_panic_handling! {
-        let this=unsafe{ this.transmute_into_ref::<DebugDisplay>() };
+        let this = unsafe{ this.transmute_into_ref::<DebugDisplay>() };
         ROption::RSome(DebugDisplayRef{
             debug: this.debug.as_str().into(),
             display: this.display.as_str().into(),
@@ -876,5 +812,3 @@ unsafe extern "C" fn not_as_debug_display(
 ) -> ROption<DebugDisplayRef<'_>> {
     ROption::RNone
 }
-
-
