@@ -1,16 +1,14 @@
-/*!
-Contains an ffi-safe equivalent of `std::string::String`.
-*/
+//! Contains an ffi-safe equivalent of `std::string::String`.
 
 use std::{
-    borrow::{Cow,Borrow},
+    borrow::{Borrow, Cow},
     fmt::{self, Display, Formatter},
     iter::{FromIterator, FusedIterator},
     marker::PhantomData,
     ops::{Deref, Index, Range},
-    str::{from_utf8, from_utf8_unchecked, Chars,FromStr, Utf8Error},
-    string::FromUtf16Error,
     ptr,
+    str::{from_utf8, from_utf8_unchecked, Chars, FromStr, Utf8Error},
+    string::FromUtf16Error,
 };
 
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
@@ -23,36 +21,31 @@ use crate::std_types::{RStr, RVec};
 mod iters;
 
 #[cfg(test)]
-// #[cfg(all(test,not(feature="only_new_tests")))]
+// #[cfg(all(test, not(feature = "only_new_tests")))]
 mod tests;
 
 pub use self::iters::{Drain, IntoIter};
 
-/**
-Ffi-safe equivalent of `std::string::String`.
-
-# Example
-
-This defines a function returning the last word of an `RString`.
-
-```
-use abi_stable::{
-    std_types::RString,
-    sabi_extern_fn,
-};
-
-
-#[sabi_extern_fn]
-fn first_word(phrase:RString)->RString{
-    match phrase.split_whitespace().next_back() {
-        Some(x)=>x.into(),
-        None=>RString::new(),
-    }
-}
-
-```
-
-*/
+/// Ffi-safe equivalent of `std::string::String`.
+///
+/// # Example
+///
+/// This defines a function returning the last word of an `RString`.
+///
+/// ```
+/// use abi_stable::{sabi_extern_fn, std_types::RString};
+///
+/// #[sabi_extern_fn]
+/// fn first_word(phrase: RString) -> RString {
+///     match phrase.split_whitespace().next_back() {
+///         Some(x) => x.into(),
+///         None => RString::new(),
+///     }
+/// }
+///
+///
+/// ```
+///
 #[derive(Clone)]
 #[repr(C)]
 #[derive(StableAbi)]
@@ -61,23 +54,23 @@ pub struct RString {
 }
 
 impl RString {
-    /// Creates a new,empty RString.
+    /// Creates a new, empty RString.
     ///
     /// # Example
     ///
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let str=RString::new();
-    /// 
-    /// assert_eq!(&str[..],"");
+    /// let str = RString::new();
+    ///
+    /// assert_eq!(&str[..], "");
     ///
     /// ```
     pub const fn new() -> Self {
         Self::NEW
     }
 
-    const NEW:Self=Self{ inner:RVec::new() };
+    const NEW: Self = Self { inner: RVec::new() };
 
     /// Creates a new,
     /// empty RString with the capacity for `cap` bytes without reallocating.
@@ -87,13 +80,13 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let str=RString::with_capacity(10);
-    /// 
-    /// assert_eq!(&str[..],"");
-    /// assert_eq!(str.capacity(),10);
+    /// let str = RString::with_capacity(10);
+    ///
+    /// assert_eq!(&str[..], "");
+    /// assert_eq!(str.capacity(), 10);
     ///
     /// ```
-    pub fn with_capacity(cap:usize) -> Self {
+    pub fn with_capacity(cap: usize) -> Self {
         String::with_capacity(cap).into()
     }
 
@@ -105,14 +98,14 @@ impl RString {
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RStr,RString};
+    /// use abi_stable::std_types::{RStr, RString};
     ///
-    /// let str=RString::from("What is that.");
-    /// 
-    /// assert_eq!(str.slice(..),RStr::from("What is that."));
-    /// assert_eq!(str.slice(..4),RStr::from("What"));
-    /// assert_eq!(str.slice(4..),RStr::from(" is that."));
-    /// assert_eq!(str.slice(4..7),RStr::from(" is"));
+    /// let str = RString::from("What is that.");
+    ///
+    /// assert_eq!(str.slice(..), RStr::from("What is that."));
+    /// assert_eq!(str.slice(..4), RStr::from("What"));
+    /// assert_eq!(str.slice(4..), RStr::from(" is that."));
+    /// assert_eq!(str.slice(4..7), RStr::from(" is"));
     ///
     /// ```
     #[inline]
@@ -131,8 +124,8 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let str="What is that.";
-    /// assert_eq!(RString::from(str).as_str(),str);
+    /// let str = "What is that.";
+    /// assert_eq!(RString::from(str).as_str(), str);
     ///
     /// ```
     #[inline]
@@ -145,20 +138,15 @@ impl RString {
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RStr,RString};
+    /// use abi_stable::std_types::{RStr, RString};
     ///
-    /// let str="What is that.";
-    /// assert_eq!(
-    ///     RString::from(str).as_rstr(),
-    ///     RStr::from(str),
-    /// );
+    /// let str = "What is that.";
+    /// assert_eq!(RString::from(str).as_rstr(), RStr::from(str),);
     ///
     /// ```
     #[inline]
     pub const fn as_rstr(&self) -> RStr<'_> {
-        unsafe{
-            RStr::from_raw_parts(self.as_ptr(),self.len())
-        }
+        unsafe { RStr::from_raw_parts(self.as_ptr(), self.len()) }
     }
 
     /// Returns the current length (in bytes) of the RString.
@@ -168,9 +156,9 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// assert_eq!(RString::from("").len(),0);
-    /// assert_eq!(RString::from("a").len(),1);
-    /// assert_eq!(RString::from("Regular").len(),7);
+    /// assert_eq!(RString::from("").len(), 0);
+    /// assert_eq!(RString::from("a").len(), 1);
+    /// assert_eq!(RString::from("Regular").len(), 7);
     ///
     /// ```
     #[inline]
@@ -196,11 +184,10 @@ impl RString {
     }
 
     /// Gets a raw pointer to the start of this RString's buffer.
-    pub const fn as_ptr(&self) -> *const u8{
+    pub const fn as_ptr(&self) -> *const u8 {
         self.inner.as_ptr()
     }
 
-
     /// Returns the current capacity (in bytes) of the RString.
     ///
     /// # Example
@@ -208,15 +195,15 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::with_capacity(13);
+    /// let mut str = RString::with_capacity(13);
     ///
-    /// assert_eq!(str.capacity(),13);
+    /// assert_eq!(str.capacity(), 13);
     ///
     /// str.push_str("What is that.");
-    /// assert_eq!(str.capacity(),13);
+    /// assert_eq!(str.capacity(), 13);
     ///
     /// str.push(' ');
-    /// assert_ne!(str.capacity(),13);
+    /// assert_ne!(str.capacity(), 13);
     ///
     /// ```
     #[inline]
@@ -228,24 +215,24 @@ impl RString {
     ///
     /// # Safety
     ///
-    /// This has the same safety requirements as 
+    /// This has the same safety requirements as
     /// [`String::from_utf8_unchecked`
     /// ](https://doc.rust-lang.org/std/string/struct.String.html#method.from_utf8_unchecked).
     ///
     /// # Examples
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let bytes=RVec::from("hello".as_bytes());
+    /// let bytes = RVec::from("hello".as_bytes());
     ///
-    /// unsafe{
-    ///     assert_eq!( RString::from_utf8_unchecked(bytes).as_str(), "hello" );
+    /// unsafe {
+    ///     assert_eq!(RString::from_utf8_unchecked(bytes).as_str(), "hello");
     /// }
     ///
     /// ```
     #[inline]
-    pub const unsafe fn from_utf8_unchecked(vec: RVec<u8>) -> Self{
+    pub const unsafe fn from_utf8_unchecked(vec: RVec<u8>) -> Self {
         RString { inner: vec }
     }
 
@@ -258,13 +245,16 @@ impl RString {
     /// # Examples
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let bytes_ok=RVec::from("hello".as_bytes());
-    /// let bytes_err=RVec::from(vec![255]);
+    /// let bytes_ok = RVec::from("hello".as_bytes());
+    /// let bytes_err = RVec::from(vec![255]);
     ///
-    /// assert_eq!( RString::from_utf8(bytes_ok).unwrap(), RString::from("hello") );
-    /// assert!( RString::from_utf8(bytes_err).is_err() );
+    /// assert_eq!(
+    ///     RString::from_utf8(bytes_ok).unwrap(),
+    ///     RString::from("hello")
+    /// );
+    /// assert!(RString::from_utf8(bytes_err).is_err());
     ///
     /// ```
     pub fn from_utf8<V>(vec: V) -> Result<Self, FromUtf8Error>
@@ -281,42 +271,38 @@ impl RString {
         }
     }
 
-
     /// Decodes a utf-16 encoded `&[u16]` to an `RString`.
     ///
     /// # Errors
     ///
-    /// This returns a `Err(::std::string::FromUtf16Error{..})` 
+    /// This returns a `Err(::std::string::FromUtf16Error{..})`
     /// if `vec` is not valid utf-8.
     ///
     /// # Example
     ///
     /// ```
     /// use abi_stable::std_types::RString;
-    /// 
-    /// let str="What the 😈.";
-    /// let str_utf16=str.encode_utf16().collect::<Vec<u16>>();
     ///
-    /// assert_eq!(
-    ///     RString::from_utf16(&str_utf16).unwrap(),
-    ///     RString::from(str),
-    /// );
+    /// let str = "What the 😈.";
+    /// let str_utf16 = str.encode_utf16().collect::<Vec<u16>>();
+    ///
+    /// assert_eq!(RString::from_utf16(&str_utf16).unwrap(), RString::from(str),);
     /// ```
     pub fn from_utf16(s: &[u16]) -> Result<Self, FromUtf16Error> {
         String::from_utf16(s).map(From::from)
     }
 
-    /// Cheap conversion of this `RString` to a `RVec<u8>` 
+    /// Cheap conversion of this `RString` to a `RVec<u8>`
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let bytes=RVec::from("hello".as_bytes());
-    /// let str=RString::from("hello");
+    /// let bytes = RVec::from("hello".as_bytes());
+    /// let str = RString::from("hello");
     ///
-    /// assert_eq!(str.into_bytes(),bytes);
+    /// assert_eq!(str.into_bytes(), bytes);
     ///
     /// ```
     pub fn into_bytes(self) -> RVec<u8> {
@@ -335,10 +321,10 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let std_str=String::from("hello");
-    /// let str=RString::from("hello");
+    /// let std_str = String::from("hello");
+    /// let str = RString::from("hello");
     ///
-    /// assert_eq!(str.into_string(),std_str);
+    /// assert_eq!(str.into_string(), std_str);
     ///
     /// ```
     pub fn into_string(self) -> String {
@@ -358,7 +344,7 @@ impl RString {
     pub fn to_string(&self) -> String {
         self.as_str().to_string()
     }
-    
+
     /// Reserves `àdditional` additional capacity for any extra string data.
     /// This may reserve more than necessary for the additional capacity.
     ///
@@ -367,10 +353,10 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::new();
+    /// let mut str = RString::new();
     ///
     /// str.reserve(10);
-    /// assert!(str.capacity()>=10);
+    /// assert!(str.capacity() >= 10);
     ///
     /// ```
     pub fn reserve(&mut self, additional: usize) {
@@ -384,10 +370,10 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::with_capacity(100);
+    /// let mut str = RString::with_capacity(100);
     /// str.push_str("nope");
     /// str.shrink_to_fit();
-    /// assert_eq!(str.capacity(),4);
+    /// assert_eq!(str.capacity(), 4);
     ///
     /// ```
     pub fn shrink_to_fit(&mut self) {
@@ -395,7 +381,7 @@ impl RString {
     }
 
     /// Reserves `àdditional` additional capacity for any extra string data.
-    /// 
+    ///
     /// Prefer using `reserve` for most situations.
     ///
     /// # Example
@@ -403,10 +389,10 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::new();
+    /// let mut str = RString::new();
     ///
     /// str.reserve_exact(10);
-    /// assert_eq!(str.capacity(),10);
+    /// assert_eq!(str.capacity(), 10);
     ///
     /// ```
     pub fn reserve_exact(&mut self, additional: usize) {
@@ -420,13 +406,13 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::new();
+    /// let mut str = RString::new();
     ///
     /// str.push('O');
     /// str.push('O');
     /// str.push('P');
     ///
-    /// assert_eq!(str.as_str(),"OOP");
+    /// assert_eq!(str.as_str(), "OOP");
     ///
     /// ```
     pub fn push(&mut self, ch: char) {
@@ -443,12 +429,12 @@ impl RString {
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let mut str=RString::new();
+    /// let mut str = RString::new();
     ///
     /// str.push_str("green ");
     /// str.push_str("frog");
     ///
-    /// assert_eq!(str.as_str(),"green frog");
+    /// assert_eq!(str.as_str(), "green frog");
     ///
     /// ```
     pub fn push_str(&mut self, str: &str) {
@@ -462,18 +448,18 @@ impl RString {
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let mut str=RString::from("yep");
+    /// let mut str = RString::from("yep");
     ///
-    /// assert_eq!(str.pop(),Some('p'));
-    /// assert_eq!(str.pop(),Some('e'));
-    /// assert_eq!(str.pop(),Some('y'));
-    /// assert_eq!(str.pop(),None);
+    /// assert_eq!(str.pop(), Some('p'));
+    /// assert_eq!(str.pop(), Some('e'));
+    /// assert_eq!(str.pop(), Some('y'));
+    /// assert_eq!(str.pop(), None);
     ///
     /// ```
-    pub fn pop(&mut self)->Option<char>{
-        // literal copy-paste of std,so if this is wrong std is wrong.
+    pub fn pop(&mut self) -> Option<char> {
+        // literal copy-paste of std, so if this is wrong std is wrong.
 
         let ch = self.chars().rev().next()?;
         let newlen = self.len() - ch.len_utf8();
@@ -484,27 +470,27 @@ impl RString {
     }
 
     /// Removes and returns the character starting at the `idx` byte position,
-    /// 
+    ///
     /// # Panics
-    /// 
+    ///
     /// Panics if the index is out of bounds or if it is not on a char boundary.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let mut str=RString::from("Galileo");
+    /// let mut str = RString::from("Galileo");
     ///
-    /// assert_eq!(str.remove(3),'i');
-    /// assert_eq!(str.as_str(),"Galleo");
+    /// assert_eq!(str.remove(3), 'i');
+    /// assert_eq!(str.as_str(), "Galleo");
     ///
-    /// assert_eq!(str.remove(4),'e');
-    /// assert_eq!(str.as_str(),"Gallo");
+    /// assert_eq!(str.remove(4), 'e');
+    /// assert_eq!(str.as_str(), "Gallo");
     ///
     /// ```
-    pub fn remove(&mut self,idx:usize)->char{
-        // literal copy-paste of std,so if this is wrong std is wrong.
+    pub fn remove(&mut self, idx: usize) -> char {
+        // literal copy-paste of std, so if this is wrong std is wrong.
 
         let ch = match self[idx..].chars().next() {
             Some(ch) => ch,
@@ -515,11 +501,7 @@ impl RString {
         let len = self.len();
         unsafe {
             let ptr = self.inner.as_mut_ptr();
-            ptr::copy(
-                ptr.add(next),
-                ptr.add(idx),
-                len - next
-            );
+            ptr::copy(ptr.add(next), ptr.add(idx), len - next);
             self.inner.set_len(len - (next - idx));
         }
         ch
@@ -528,24 +510,24 @@ impl RString {
     /// Insert the `ch` character at the `ìdx` byte position.
     ///
     /// # Panics
-    /// 
+    ///
     /// Panics if the index is out of bounds or if it is not on a char boundary.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let mut str=RString::from("Cap");
+    /// let mut str = RString::from("Cap");
     ///
-    /// str.insert(1,'r');
-    /// assert_eq!(str.as_str(),"Crap");
+    /// str.insert(1, 'r');
+    /// assert_eq!(str.as_str(), "Crap");
     ///
-    /// str.insert(4,'p');
-    /// assert_eq!(str.as_str(),"Crapp");
+    /// str.insert(4, 'p');
+    /// assert_eq!(str.as_str(), "Crapp");
     ///
-    /// str.insert(5,'y');
-    /// assert_eq!(str.as_str(),"Crappy");
+    /// str.insert(5, 'y');
+    /// assert_eq!(str.as_str(), "Crappy");
     ///
     /// ```
     pub fn insert(&mut self, idx: usize, ch: char) {
@@ -558,29 +540,29 @@ impl RString {
     /// Insert the `string` at the `ìdx` byte position.
     ///
     /// # Panics
-    /// 
+    ///
     /// Panics if the index is out of bounds or if it is not on a char boundary.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let mut str=RString::from("rust");
+    /// let mut str = RString::from("rust");
     ///
-    /// str.insert_str(0,"T");
-    /// assert_eq!(str.as_str(),"Trust");
+    /// str.insert_str(0, "T");
+    /// assert_eq!(str.as_str(), "Trust");
     ///
-    /// str.insert_str(5," the source");
-    /// assert_eq!(str.as_str(),"Trust the source");
+    /// str.insert_str(5, " the source");
+    /// assert_eq!(str.as_str(), "Trust the source");
     ///
-    /// str.insert_str(5," the types in");
-    /// assert_eq!(str.as_str(),"Trust the types in the source");
+    /// str.insert_str(5, " the types in");
+    /// assert_eq!(str.as_str(), "Trust the types in the source");
     ///
     /// ```
     pub fn insert_str(&mut self, idx: usize, string: &str) {
-        // literal copy-paste of std,so if this is wrong std is wrong.
-        
+        // literal copy-paste of std, so if this is wrong std is wrong.
+
         assert!(self.is_char_boundary(idx));
 
         unsafe {
@@ -592,51 +574,44 @@ impl RString {
         let len = self.len();
         let amt = bytes.len();
         self.inner.reserve(amt);
-        
+
         let ptr = self.inner.as_mut_ptr();
-        ptr::copy(
-            ptr.add(idx),
-            ptr.add(idx + amt),
-            len - idx,
-        );
-        ptr::copy(
-            bytes.as_ptr(),
-            self.inner.as_mut_ptr().add(idx),
-            amt,
-        );
+        ptr::copy(ptr.add(idx), ptr.add(idx + amt), len - idx);
+        ptr::copy(bytes.as_ptr(), self.inner.as_mut_ptr().add(idx), amt);
         self.inner.set_len(len + amt);
     }
 
     /// Retains only the characters that satisfy the `pred` predicate
     ///
-    /// This means that a character will be removed if `pred(that_character)` 
+    /// This means that a character will be removed if `pred(that_character)`
     /// returns false.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
     /// {
-    ///     let mut str=RString::from("There were 10 people.");
-    ///     str.retain(|c| !c.is_numeric() );
-    ///     assert_eq!(str.as_str(),"There were  people.");
+    ///     let mut str = RString::from("There were 10 people.");
+    ///     str.retain(|c| !c.is_numeric());
+    ///     assert_eq!(str.as_str(), "There were  people.");
     /// }
     /// {
-    ///     let mut str=RString::from("There were 10 people.");
-    ///     str.retain(|c| !c.is_whitespace() );
-    ///     assert_eq!(str.as_str(),"Therewere10people.");
+    ///     let mut str = RString::from("There were 10 people.");
+    ///     str.retain(|c| !c.is_whitespace());
+    ///     assert_eq!(str.as_str(), "Therewere10people.");
     /// }
     /// {
-    ///     let mut str=RString::from("There were 10 people.");
-    ///     str.retain(|c| c.is_numeric() );
-    ///     assert_eq!(str.as_str(),"10");
+    ///     let mut str = RString::from("There were 10 people.");
+    ///     str.retain(|c| c.is_numeric());
+    ///     assert_eq!(str.as_str(), "10");
     /// }
     ///
     /// ```
     #[inline]
     pub fn retain<F>(&mut self, mut pred: F)
-    where F: FnMut(char) -> bool
+    where
+        F: FnMut(char) -> bool,
     {
         let len = self.len();
         let mut del_bytes = 0;
@@ -649,11 +624,13 @@ impl RString {
         let start = self.inner.as_mut_ptr();
 
         while idx < len {
-            let curr = unsafe{ start.add(idx) };
+            let curr = unsafe { start.add(idx) };
 
             let ch = unsafe {
                 RStr::from_raw_parts(curr, len - idx)
-                    .chars().next().unwrap()
+                    .chars()
+                    .next()
+                    .unwrap()
             };
             let ch_len = ch.len_utf8();
 
@@ -661,11 +638,7 @@ impl RString {
                 del_bytes += ch_len;
             } else if del_bytes > 0 {
                 unsafe {
-                    ptr::copy(
-                        curr,
-                        curr.sub(del_bytes),
-                        ch_len,
-                    );
+                    ptr::copy(curr, curr.sub(del_bytes), ch_len);
                 }
             }
 
@@ -678,26 +651,25 @@ impl RString {
         }
     }
 
-    /// Turns this into an empty RString,keeping the same allocated buffer.
+    /// Turns this into an empty RString, keeping the same allocated buffer.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let mut str=RString::from("Nurse");
+    /// let mut str = RString::from("Nurse");
+    ///
+    /// assert_eq!(str.as_str(), "Nurse");
     ///
-    /// assert_eq!(str.as_str(),"Nurse");
-    /// 
     /// str.clear();
-    /// 
-    /// assert_eq!(str.as_str(),"");
+    ///
+    /// assert_eq!(str.as_str(), "");
     ///
     /// ```
-    pub fn clear(&mut self){
+    pub fn clear(&mut self) {
         self.inner.clear();
     }
-
 }
 
 /// Returns an empty RString
@@ -709,10 +681,10 @@ impl Default for RString {
 
 ////////////////////
 
-deref_coerced_impl_cmp_traits!{
+deref_coerced_impl_cmp_traits! {
     RString;
     coerce_to = str,
-    [   
+    [
         String,
         str,
         &str,
@@ -722,7 +694,6 @@ deref_coerced_impl_cmp_traits!{
     ]
 }
 
-
 ////////////////////
 
 impl_into_rust_repr! {
@@ -733,14 +704,14 @@ impl_into_rust_repr! {
     }
 }
 
-impl<'a> Into<Cow<'a, str>> for RString {
-    fn into(self) -> Cow<'a, str> {
-        self.into_string().piped(Cow::Owned)
+impl<'a> From<RString> for Cow<'a, str> {
+    fn from(this: RString) -> Cow<'a, str> {
+        this.into_string().piped(Cow::Owned)
     }
 }
 
-impl<'a> From<&'a str> for RString {
-    fn from(this: &'a str) -> Self {
+impl From<&str> for RString {
+    fn from(this: &str) -> Self {
         this.to_owned().into()
     }
 }
@@ -763,7 +734,6 @@ impl<'a> From<Cow<'a, str>> for RString {
 
 ////////////////////
 
-
 impl FromStr for RString {
     type Err = <String as FromStr>::Err;
 
@@ -772,32 +742,28 @@ impl FromStr for RString {
     }
 }
 
-
 ////////////////////
 
-
-impl Borrow<str> for RString{
-    fn borrow(&self)->&str{
+impl Borrow<str> for RString {
+    fn borrow(&self) -> &str {
         self
     }
 }
 
-impl AsRef<str> for RString{
-    fn as_ref(&self)->&str{
+impl AsRef<str> for RString {
+    fn as_ref(&self) -> &str {
         self
     }
 }
 
-impl AsRef<[u8]> for RString{
-    fn as_ref(&self)->&[u8]{
+impl AsRef<[u8]> for RString {
+    fn as_ref(&self) -> &[u8] {
         self.as_bytes()
     }
 }
 
-
 ////////////////////
 
-
 impl Deref for RString {
     type Target = str;
 
@@ -828,9 +794,9 @@ impl fmt::Write for RString {
 }
 
 shared_impls! {
-    mod=string_impls
-    new_type=RString[][],
-    original_type=str,
+    mod = string_impls
+    new_type = RString[][],
+    original_type = str,
 }
 
 impl<'de> Deserialize<'de> for RString {
@@ -854,58 +820,43 @@ impl Serialize for RString {
 //////////////////////////////////////////////////////
 
 impl RString {
-    /**
-Creates an iterator that yields the chars in the `range`,
-removing the characters in that range in the process.
-
-# Panic
-
-Panics if the start or end of the range are not on a on a char boundary, 
-or if either are out of bounds.
-
-# Example
-
-```
-use abi_stable::std_types::RString;
-
-let orig="Not a single way";
-
-{
-    let mut str=RString::from(orig);
-    assert_eq!(
-        str.drain(..).collect::<String>(),
-        orig,
-    );
-    assert_eq!(str.as_str(),"");
-}
-{
-    let mut str=RString::from(orig);
-    assert_eq!(
-        str.drain(..4).collect::<String>(),
-        "Not ",
-    );
-    assert_eq!(str.as_str(),"a single way");
-}
-{
-    let mut str=RString::from(orig);
-    assert_eq!(
-        str.drain(4..).collect::<String>(),
-        "a single way",
-    );
-    assert_eq!(str.as_str(),"Not ");
-}
-{
-    let mut str=RString::from(orig);
-    assert_eq!(
-        str.drain(4..13).collect::<String>(),
-        "a single ",
-    );
-    assert_eq!(str.as_str(),"Not way");
-}
-
-```
-
-    */
+    /// Creates an iterator that yields the chars in the `range`,
+    /// removing the characters in that range in the process.
+    ///
+    /// # Panic
+    ///
+    /// Panics if the start or end of the range are not on a on a char boundary,
+    /// or if either are out of bounds.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use abi_stable::std_types::RString;
+    ///
+    /// let orig = "Not a single way";
+    ///
+    /// {
+    ///     let mut str = RString::from(orig);
+    ///     assert_eq!(str.drain(..).collect::<String>(), orig,);
+    ///     assert_eq!(str.as_str(), "");
+    /// }
+    /// {
+    ///     let mut str = RString::from(orig);
+    ///     assert_eq!(str.drain(..4).collect::<String>(), "Not ",);
+    ///     assert_eq!(str.as_str(), "a single way");
+    /// }
+    /// {
+    ///     let mut str = RString::from(orig);
+    ///     assert_eq!(str.drain(4..).collect::<String>(), "a single way",);
+    ///     assert_eq!(str.as_str(), "Not ");
+    /// }
+    /// {
+    ///     let mut str = RString::from(orig);
+    ///     assert_eq!(str.drain(4..13).collect::<String>(), "a single ",);
+    ///     assert_eq!(str.as_str(), "Not way");
+    /// }
+    ///
+    /// ```
     pub fn drain<I>(&mut self, range: I) -> Drain<'_>
     where
         str: Index<I, Output = str>,
@@ -918,7 +869,7 @@ let orig="Not a single way";
             string,
             removed: start..end,
             iter: slic_.chars(),
-            variance:PhantomData,
+            variance: PhantomData,
         }
     }
 }
@@ -932,11 +883,9 @@ impl IntoIterator for RString {
         unsafe {
             // Make sure that the buffer is not deallocated as long as the iterator is accessible.
             let text: &'static str = &*(&*self as *const str);
-            unsafe {
-                IntoIter {
-                    iter: text.chars(),
-                    _buf: self,
-                }
+            IntoIter {
+                iter: text.chars(),
+                _buf: self,
             }
         }
     }
@@ -969,9 +918,9 @@ impl<'a> FromIterator<&'a char> for RString {
 /// ```
 /// use abi_stable::std_types::RString;
 ///
-/// let err=RString::from_utf8(vec![0,0,0,255]).unwrap_err();
+/// let err = RString::from_utf8(vec![0, 0, 0, 255]).unwrap_err();
 ///
-/// assert_eq!( err.as_bytes() , &[0,0,0,255] )
+/// assert_eq!(err.as_bytes(), &[0, 0, 0, 255])
 ///
 /// ```
 #[derive(Debug)]
@@ -980,22 +929,22 @@ pub struct FromUtf8Error {
     error: Utf8Error,
 }
 
-impl FromUtf8Error{
+impl FromUtf8Error {
     /// Unwraps this error into the bytes that failed to be converted into an `RString`.
     ///
     /// # Example
     ///
     /// ```
-    /// use abi_stable::std_types::{RString,RVec};
+    /// use abi_stable::std_types::{RString, RVec};
     ///
-    /// let bytes:RVec<u8>= vec![72, 111, 95, 95, 95, 95, 95, 99, 107, 255].into();
+    /// let bytes: RVec<u8> = vec![72, 111, 95, 95, 95, 95, 95, 99, 107, 255].into();
     ///
-    /// let err=RString::from_utf8(bytes.clone()).unwrap_err();
+    /// let err = RString::from_utf8(bytes.clone()).unwrap_err();
     ///
-    /// assert_eq!( err.into_bytes(), bytes );
+    /// assert_eq!(err.into_bytes(), bytes);
     ///
     /// ```
-    pub fn into_bytes(self)->RVec<u8>{
+    pub fn into_bytes(self) -> RVec<u8> {
         self.bytes
     }
     /// Gets access to the bytes that failed to be converted into an `RString`.
@@ -1005,14 +954,14 @@ impl FromUtf8Error{
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let bytes= vec![99, 114, 121, 115, 116, 97, 108, 255];
+    /// let bytes = vec![99, 114, 121, 115, 116, 97, 108, 255];
     ///
-    /// let err=RString::from_utf8(bytes.clone()).unwrap_err();
+    /// let err = RString::from_utf8(bytes.clone()).unwrap_err();
     ///
-    /// assert_eq!( err.as_bytes(), &bytes[..] );
+    /// assert_eq!(err.as_bytes(), &bytes[..]);
     ///
     /// ```
-    pub fn as_bytes(&self)->&[u8]{
+    pub fn as_bytes(&self) -> &[u8] {
         &self.bytes
     }
 
@@ -1023,12 +972,12 @@ impl FromUtf8Error{
     /// ```
     /// use abi_stable::std_types::RString;
     ///
-    /// let err=RString::from_utf8( vec![0, 0, 255] ).unwrap_err();
+    /// let err = RString::from_utf8(vec![0, 0, 255]).unwrap_err();
     ///
-    /// assert_eq!( err.error().valid_up_to(), 2 );
+    /// assert_eq!(err.error().valid_up_to(), 2);
     ///
     /// ```
-    pub fn error(&self)->Utf8Error{
+    pub fn error(&self) -> Utf8Error {
         self.error
     }
 }
@@ -1039,4 +988,4 @@ impl fmt::Display for FromUtf8Error {
     }
 }
 
-impl std::error::Error for FromUtf8Error{}
\ No newline at end of file
+impl std::error::Error for FromUtf8Error {}
